# Wirtual Plugins Silero

Agent Framework Plugin for Silero. Currently supports Voice Activity Detection.

## Installation

```bash
pip install wirtual-plugins-silero
```

This plugin contains model files that would need to be downloaded prior to use.
